function [A,c] = SetupNautyGraph_packed(Gtilde)
%SETUPNAUTYGRAPH_SPARSE converts a characteristic graph Gtilde from the 
%format produced by the GenerateCharacteristicGraph function to a packed 
%format readable by Nauty.
%
% INPUT:  Gtilde is a vertex-colored equivalent of a characteristic graph G
%         which is an output of the function GenerateCharacteristicGraph. 
%         (See GenerateChararcteristicGraph help for more details).
%
% OUTPUT: A is an n by n binary matrix where n is the number of vertices of
%         a graph. It is the adjacency matrix of Gtilde. 
%
%         c is a 2 by n matrix. The first row lists the vertices (vertices 
%         are labeled 1 to n) in some order such that vertices of the same 
%         color are continuous. The second row splits the listed vertices
%         into different color classes. The ends of the color classes are 
%         indicated by zeros.
%
% See also, SetupNautyGraph_sparse, CallNauty_packed.c
%             
% Author:   Scott Bugenhagen
% Contact:  sbugenha@mcw.edu
% Date:     8/30/2011
%
% References:
% 1. McKay, BD. Nauty user's guide (version 2.4). Australian National 
%    University, 2009. Retrieved from <http://cs.anu.edu.au/~bdm/nauty/> 
%    on 6/1/2011.

L = Gtilde{1,1};
Utilde = Gtilde{1,2};
c = ones(2,length(L));
[Lsort,c(1,:)] = sort(L);
[~,ends] = unique(Lsort);
c(2,ends) = 0;
A = sparse(Utilde(:,1),Utilde(:,2),1);
A = full(A);
end