function [C] = cartprod(input)
%CARTPROD computes the cartesian product of multiple sets.
%
% INPUT:  input is a cell array with each cell containing a numeric matrix
%         representing a set whos elements are the matrix rows. Note that
%         this function does not check for non-unique rows.
%
% OUTPUT: C is a numeric array representing the product set of each input
%         set.
%
% Author:   Scott Bugenhagen
% Contact:  sbugenha@mcw.edu
% Date:     8/30/11
%
% References: 
% 1. http://en.wikipedia.org/wiki/Cartesian_product

nargin = length(input);
Cnrows = 1;
Cmcols = 0;
Anrows = zeros(1,nargin);
Amcols = zeros(1,nargin);
for i = 1:nargin
    Anrows(i) = size(input{i},1);
    Amcols(i) = size(input{i},2);
    Cnrows = Cnrows*Anrows(i);
    Cmcols = Cmcols + Amcols(i);
end
C = zeros(Cnrows,Cmcols);
b = 1;
Cix = 0;
for i = 1:nargin
    Cblk = kron(input{i},ones(b,1));
    Cblknrows = size(Cblk,1);
    C(:,Cix+1:Cix+Amcols(i)) = repmat(Cblk,Cnrows/Cblknrows,1);
    Cix = Cix + Amcols(i);
    b = b*Anrows(i);
end
end